==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealInformacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaRealInformacjaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long informacjaId;

    /**
     * DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long diagnozaRealId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getInformacjaId() {
        return informacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     *
     * @param informacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setInformacjaId(Long informacjaId) {
        this.informacjaId = informacjaId;
    }

    /**
     * @return DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDiagnozaRealId() {
        return diagnozaRealId;
    }

    /**
     * DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     *
     * @param diagnozaRealId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDiagnozaRealId(Long diagnozaRealId) {
        this.diagnozaRealId = diagnozaRealId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealInformacjaKey other = (DiagnozaRealInformacjaKey) that;
        return (this.getInformacjaId() == null ? other.getInformacjaId() == null : this.getInformacjaId().equals(other.getInformacjaId()))
            && (this.getDiagnozaRealId() == null ? other.getDiagnozaRealId() == null : this.getDiagnozaRealId().equals(other.getDiagnozaRealId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInformacjaId() == null) ? 0 : getInformacjaId().hashCode());
        result = prime * result + ((getDiagnozaRealId() == null) ? 0 : getDiagnozaRealId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", informacjaId=").append(informacjaId);
        sb.append(", diagnozaRealId=").append(diagnozaRealId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/DiagnozaRealInformacjaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class DiagnozaRealInformacjaKey extends GenericDPSObject {
    /**
     * DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long informacjaId;

    /**
     * DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long diagnozaRealId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getInformacjaId() {
        return informacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:47
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * DIAGNOZA_REAL_INFORMACJA.INFORMACJA_ID
     *
     * @param informacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setInformacjaId(Long informacjaId) {
        this.informacjaId = informacjaId;
    }

    /**
     * @return DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDiagnozaRealId() {
        return diagnozaRealId;
    }

    /**
     * DIAGNOZA_REAL_INFORMACJA.DIAGNOZA_REAL_ID
     *
     * @param diagnozaRealId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDiagnozaRealId(Long diagnozaRealId) {
        this.diagnozaRealId = diagnozaRealId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        DiagnozaRealInformacjaKey other = (DiagnozaRealInformacjaKey) that;
        return (this.getInformacjaId() == null ? other.getInformacjaId() == null : this.getInformacjaId().equals(other.getInformacjaId()))
            && (this.getDiagnozaRealId() == null ? other.getDiagnozaRealId() == null : this.getDiagnozaRealId().equals(other.getDiagnozaRealId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getInformacjaId() == null) ? 0 : getInformacjaId().hashCode());
        result = prime * result + ((getDiagnozaRealId() == null) ? 0 : getDiagnozaRealId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", informacjaId=").append(informacjaId);
        sb.append(", diagnozaRealId=").append(diagnozaRealId);
        sb.append("]");
        return sb.toString();
    }
}
